| Title: | Tabular Reporting of 'EViews' Unit Root Tests |
|---|---|
| Description: | Conduct unit root tests based on 'EViews' (<https://eviews.com>) routines and report them in tables. 'EViews' (Econometric Views) is a commercial software for econometrics. |
| Authors: | Sagiru Mati [aut, cre] (ORCID: <https://orcid.org/0000-0003-1413-3974>) |
| Maintainer: | Sagiru Mati <[email protected]> |
| License: | GPL |
| Version: | 0.1.0 |
| Built: | 2026-05-26 06:58:22 UTC |
| Source: | https://github.com/sagirumati/urootab |
ADF unit root test using EViews routinesUse this function to conduct ADF unit root test using EViews routines
adf(series, info = "sic", caption = NULL, format = kable_format(), ...)adf(series, info = "sic", caption = NULL, format = kable_format(), ...)
series |
A vector of names or wildcard expressions for series object(s) contained in a dataframe. |
info |
Name of the information criterion. For example, |
caption |
Table caption as in |
format |
Table format in |
... |
Other arguments supported by |
An EViews workfile
Other important functions:
pp()
library(URooTab) set.seed(1234) x=rnorm(100) y=cumsum(x) z=cumsum(y) dataFrame=data.frame(x,y,z) # Check if `EViews` is installed before running the tests eviewsExecutables=c('eviews','eviews10',paste0('Eviews',9:13,'_X',c(86,64))) if(any(Sys.which(eviewsExecutables)!="")) adf(series=dataFrame,format="latex",info="aic")library(URooTab) set.seed(1234) x=rnorm(100) y=cumsum(x) z=cumsum(y) dataFrame=data.frame(x,y,z) # Check if `EViews` is installed before running the tests eviewsExecutables=c('eviews','eviews10',paste0('Eviews',9:13,'_X',c(86,64))) if(any(Sys.which(eviewsExecutables)!="")) adf(series=dataFrame,format="latex",info="aic")
PP unit root test using EViews routinesUse this function to conduct PP unit root test using EViews routines and report it in a table.
pp(series, info = "sic", caption = NULL, format = kable_format(), ...)pp(series, info = "sic", caption = NULL, format = kable_format(), ...)
series |
A vector of names or wildcard expressions for series object(s) contained in a dataframe. |
info |
Name of the information criterion. For example, |
caption |
Table caption as in |
format |
Table format in |
... |
Other arguments supported by |
An EViews workfile
Other important functions:
adf()
library(URooTab) set.seed(1234) x=rnorm(100) y=cumsum(x) z=cumsum(y) dataFrame=data.frame(x,y,z) # Check if `EViews` is installed before running the tests eviewsExecutables=c('eviews','eviews10',paste0('Eviews',9:13,'_X',c(86,64))) if(any(Sys.which(eviewsExecutables)!="")) pp(series=dataFrame,format="html",info="hq")library(URooTab) set.seed(1234) x=rnorm(100) y=cumsum(x) z=cumsum(y) dataFrame=data.frame(x,y,z) # Check if `EViews` is installed before running the tests eviewsExecutables=c('eviews','eviews10',paste0('Eviews',9:13,'_X',c(86,64))) if(any(Sys.which(eviewsExecutables)!="")) pp(series=dataFrame,format="html",info="hq")
EViews routinesUse this function to conduct unit root test using EViews routines
uroot( series, test = c("adf", "pp"), info = "sic", caption = NULL, format = kable_format(), ... )uroot( series, test = c("adf", "pp"), info = "sic", caption = NULL, format = kable_format(), ... )
series |
A vector of names or wildcard expressions for series object(s) contained in a dataframe. |
test |
Name of the unit root test. For example, |
info |
Name of the information criterion. For example, |
caption |
Table caption as in |
format |
Table format in |
... |
Other arguments supported by |
An EViews workfile
library(URooTab) set.seed(1234) x=rnorm(100) y=cumsum(x) z=cumsum(y) dataFrame=data.frame(x,y,z) # Check if `EViews` is installed before running the tests eviewsExecutables=c('eviews','eviews10',paste0('Eviews',9:13,'_X',c(86,64))) if(any(Sys.which(eviewsExecutables)!="")) uroot(series=dataFrame,format="markdown",info="sic")library(URooTab) set.seed(1234) x=rnorm(100) y=cumsum(x) z=cumsum(y) dataFrame=data.frame(x,y,z) # Check if `EViews` is installed before running the tests eviewsExecutables=c('eviews','eviews10',paste0('Eviews',9:13,'_X',c(86,64))) if(any(Sys.which(eviewsExecutables)!="")) uroot(series=dataFrame,format="markdown",info="sic")